@@ -7,7 +7,8 @@ from netbox_storage.api.views import (
     LogicalVolumeViewSet,
     PartitionViewSet,
     PhysicalVolumeViewSet,
-    VolumeGroupViewSet
+    VolumeGroupViewSet,
+    LinuxVolumeViewSet
 )
 
 router = NetBoxRouter()
@@ -19,5 +20,6 @@ router.register("logicalvolume", LogicalVolumeViewSet)
 router.register("partition", PartitionViewSet)
 router.register("physicalvolume", PhysicalVolumeViewSet)
 router.register("volumegroup", VolumeGroupViewSet)
+router.register("linuxvolume", LinuxVolumeViewSet)
 
 urlpatterns = router.urls
