@@ -1,7 +1,7 @@
 from django.core.validators import MinValueValidator
 from django.forms import (
     CharField,
-    IntegerField,
+    FloatField,
 )
 
 from netbox.forms import (
@@ -22,7 +22,7 @@ from virtualization.models import Cluster, ClusterType, VirtualMachine
 class DriveForm(NetBoxModelForm):
     """Form for creating a new Drive object."""
     # ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
-    size = IntegerField(
+    size = FloatField(
         label="Size (GB)",
         help_text="The size of the drive e.g. 25",
         validators=[MinValueValidator(1)],
@@ -82,7 +82,7 @@ class DriveFilterForm(NetBoxModelFilterSetForm):
 
     model = Drive
 
-    size = IntegerField(
+    size = FloatField(
         required=False,
         label="Size (GB)",
     )
@@ -129,7 +129,7 @@ class DriveImportForm(NetBoxModelImportForm):
 class DriveBulkEditForm(NetBoxModelBulkEditForm):
     model = Drive
 
-    size = IntegerField(
+    size = FloatField(
         required=False,
         label="Size (GB)",
     )
