@@ -16,7 +16,7 @@ from utilities.forms import (
 
 from django.urls import reverse_lazy
 
-from netbox_storage.models import Filesystem, LinuxVolume, VolumeGroup, Drive, Partition
+from netbox_storage.models import Filesystem, LinuxVolume, Drive, Partition
 from virtualization.models import VirtualMachine
 
 
