@@ -43,7 +43,7 @@ class PhysicalVolumeIndex(SearchIndex):
 
 @register_search
 class FilesystemIndex(SearchIndex):
-    model = models.PhysicalVolume
+    model = models.Filesystem
     fields = (
         ('filesystem', 100),
         ('description', 100),
@@ -63,7 +63,7 @@ class LogicalVolumeIndex(SearchIndex):
 
 @register_search
 class LinuxVolumeIndex(SearchIndex):
-    model = models.LogicalVolume
+    model = models.LinuxVolume
     fields = (
         ('size', 100),
         ('path', 100),
