@@ -25,6 +25,10 @@ class LinuxVolumeTable(NetBoxTable):
         linkify=True,
         verbose_name="Size"
     )
+    path = tables.Column(
+        linkify=True,
+        verbose_name="Mount Path"
+    )
 
     class Meta(NetBoxTable.Meta):
         model = LinuxVolume
