@@ -3,15 +3,15 @@ import django_tables2 as tables
 from netbox.tables import (
     NetBoxTable,
     ToggleColumn,
-    ActionsColumn,
 )
 
 from netbox_storage.models import Partition
 
 
-class PartitionBaseTable(NetBoxTable):
-    """Base class for tables displaying Partition"""
+class PartitionTable(NetBoxTable):
+    """Table for displaying Partition objects."""
 
+    pk = ToggleColumn()
     drive = tables.Column(
         linkify=True
     )
@@ -25,12 +25,6 @@ class PartitionBaseTable(NetBoxTable):
         linkify=True
     )
 
-
-class PartitionTable(PartitionBaseTable):
-    """Table for displaying Partition objects."""
-
-    pk = ToggleColumn()
-
     class Meta(NetBoxTable.Meta):
         model = Partition
         fields = (
@@ -43,22 +37,6 @@ class PartitionTable(PartitionBaseTable):
         default_columns = (
             "device",
             "size",
-            "type"
-        )
-
-
-class RelatedPartitionTable(PartitionBaseTable):
-    actions = ActionsColumn(actions=())
-
-    class Meta(NetBoxTable.Meta):
-        model = Partition
-        fields = (
-            "drive",
-            "device",
-            "size",
-        )
-        default_columns = (
-            "drive",
-            "device",
-            "size",
+            "type",
+            "description",
         )
