@@ -18,3 +18,11 @@ class LVAddSimpleView(generic.ObjectEditView):
     queryset = LinuxVolume.objects.all()
     form = LVSimpleForm
     default_return_url = "plugins:netbox_storage:drive_list"
+
+
+class AddVolume(generic.ObjectEditView):
+    """View for editing a Drive instance."""
+    template_name = "netbox_storage/inc/volume_add.html"
+    queryset = Drive.objects.all()
+    form = LVSimpleForm
+    default_return_url = "plugins:netbox_storage:drive_list"
